Summary:        User-space support for hardware monitoring drivers
Name:           lm_sensors
Version:        3.6.0
Release:        6%{?dist}
License:        GPLv2+ and LGPLv2+ and Verbatim and MIT

%define upstream_ver %(echo %{version} | tr . -)
URL:            https://hwmon.wiki.kernel.org/lm_sensors          
Source0:        https://github.com/lm-sensors/lm-sensors/archive/V%{upstream_ver}/lm-sensors-%{upstream_ver}.tar.gz
Source1:        lm_sensors.sysconfig
Source2:        sensord.sysconfig
Source3:        sensord.service
Source4:        lm_sensors.service
Source5:        lm_sensors-modprobe-wrapper
Source6:        lm_sensors-modprobe-r-wrapper
Source7:        lm_sensors-wrapper
Source8:        sensord-service-wrapper
Patch3000:      0001-Revert-unnecessary-soname-bump.patch
Patch3001:      0001-Change-PIDFile-path-from-var-run-to-run.patch
Patch3002:      lm_sensors-3.6.0-allow_no_sensors.patch
Patch3003:      lm_sensors-3.6.0-sensors-detect-Add-support-for-AMD-CPU-Family-19h.patch

BuildRequires:  gcc make bison flex gawk
BuildRequires:  kernel-headers perl-generators rrdtool-devel
Requires:       %{name}-libs = %{version}-%{release}
Requires(post): systemd-units
Requires:       /usr/sbin/modprobe
%ifarch x86_64
Requires:       /usr/sbin/dmidecode
%endif


%description
Hwmon project provides complete hardware health monitoring support for Linux,
in the form of kernel drivers and a user-space library. 
Kernel drivers provide the base software layer for utilities to acquire data
on the environmental conditions of the hardware.
User-space access library and sample text-oriented utility built on top of
said library display sensor data.
lm_sensors contains the user-space library and utilities.

Other details is on https://hwmon.wiki.kernel.org/projectinformation.


%package libs
Summary:        lm_sensors core libraries
License:        LGPLv2+

%description libs
Core libraries for lm_sensors applications.


%package devel
Summary:        Development files for lm-sensors
# lib/libsensors.3 is licensed Verbatim. Others are LGPLv2+.
License:        LGPLv2+ and Verbatim
Requires:       %{name}-libs = %{version}-%{release}

%description devel
Header files and libraries for developing applications with lm-sensors.


%package sensord
Summary:        Daemon that periodically logs sensor readings
# prog/sensord/sensord.8 is licensed Verbatim. 
License:        GPLv2+ and Verbatim and MIT
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description sensord
Daemon that periodically logs sensor readings to syslog or a round-robin
database, and warns of sensor alarms.


%prep
%autosetup -n lm-sensors-%{upstream_ver} -p1
chmod -x prog/init/fancontrol.init


%build
%{make_build}  EXLDFLAGS="$LDFLAGS" PROG_EXTRA=sensord BUILD_STATIC_LIB=0 \
               PREFIX=%{_prefix} LIBDIR=%{_libdir} MANDIR=%{_mandir}


%install
%{make_install} PROG_EXTRA=sensord BUILD_STATIC_LIB=0 \
                PREFIX=%{_prefix} LIBDIR=%{_libdir} MANDIR=%{_mandir} DESTDIR=%{buildroot}

ln -s sensors.conf.5.gz %{buildroot}%{_mandir}/man5/sensors3.conf.5.gz
mkdir -p %{buildroot}%{_sysconfdir}/sensors.d

install -D -pm 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/lm_sensors
install -D -pm 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/sensord

install -D -pm 644 %{SOURCE3} %{buildroot}%{_unitdir}/sensord.service
install -D -pm 644 %{SOURCE4} %{buildroot}%{_unitdir}/lm_sensors.service
install -D -pm 644 prog/init/fancontrol.service %{buildroot}%{_unitdir}/fancontrol.service
pushd %{buildroot}%{_unitdir}
sed -i "s|\@WRAPPER_DIR\@|%{_libexecdir}/%{name}|" sensord.service
sed -i "s|\@WRAPPER_DIR\@|%{_libexecdir}/%{name}|" lm_sensors.service
popd

install -D -pm 755 %{SOURCE5} %{buildroot}%{_libexecdir}/%{name}/lm_sensors-modprobe-wrapper
install -D -pm 755 %{SOURCE6} %{buildroot}%{_libexecdir}/%{name}/lm_sensors-modprobe-r-wrapper
install -D -pm 755 %{SOURCE7} %{buildroot}%{_libexecdir}/%{name}/lm_sensors-wrapper
install -D -pm 755 %{SOURCE8} %{buildroot}%{_libexecdir}/%{name}/sensord-service-wrapper


%post
%systemd_post lm_sensors.service

%preun
%systemd_preun lm_sensors.service

%postun
%systemd_postun_with_restart lm_sensors.service

%post sensord
%systemd_post sensord.service

%preun sensord
%systemd_preun sensord.service

%postun sensord
%systemd_postun_with_restart sensord.service


%files
%license COPYING
%doc CHANGES CONTRIBUTORS doc README*
%doc prog/init/{fancontrol.init,README}
%config %{_sysconfdir}/sensors3.conf
%config(noreplace) %{_sysconfdir}/sysconfig/lm_sensors
%dir %{_sysconfdir}/sensors.d
%{_unitdir}/lm_sensors.service
%{_unitdir}/fancontrol.service
%{_bindir}/*
%{_sbindir}/*
%exclude %{_sbindir}/sensord
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/lm_sensors-modprobe*wrapper
%{_libexecdir}/%{name}/lm_sensors-wrapper
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%exclude %{_mandir}/man8/sensord.8.gz


%files libs
%license COPYING.LGPL
%{_libdir}/*.so.*


%files devel
%{_includedir}/sensors
%{_libdir}/lib*.so
%{_mandir}/man3/*


%files sensord
%doc prog/sensord/README
%config(noreplace) %{_sysconfdir}/sysconfig/sensord
%{_unitdir}/sensord.service
%{_sbindir}/sensord
%{_libexecdir}/%{name}/sensord-service-wrapper
%{_mandir}/man8/sensord.8.gz


%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.0-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.0-5
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.0-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Jul 15 2022 rockerzhu <rockerzhu@tencent.com> - 3.6.0-1
- Initial build
